@@ -45,7 +45,7 @@ func init() {
 		"exit":                  "Exit murex",
 		"exitnum":               "Output the exit number of the previous process",
 		"export":                "Define an environmental variable and set it's value",
-		"f":                     "Lists objects (eg files) in the current working directory",
+		"f":                     "Lists or filters file system objects (eg files)",
 		"false":                 "Returns a `false` value",
 		"fexec":                 "Execute a command or function, bypassing the usual order of precedence.",
 		"fg":                    "Sends a background process into the foreground",
@@ -57,7 +57,7 @@ func init() {
 		"formap":                "Iterate through a map or other collection of data",
 		"format":                "Reformat one data-type into another data-type",
 		"function":              "Define a function block",
-		"g":                     "Glob pattern matching for file system objects (eg *.txt)",
+		"g":                     "Glob pattern matching for file system objects (eg `*.txt`)",
 		"get-type":              "Returns the data-type of a variable or pipe",
 		"get":                   "Makes a standard HTTP request and returns the result as a JSON object",
 		"getfile":               "Makes a standard HTTP request and return the contents as _murex_-aware data type for passing along _murex_ pipelines.",
@@ -100,7 +100,7 @@ func init() {
 		"right":                 "Right substring every item in a list",
 		"runmode":               "Alter the scheduler's behaviour at higher scoping level",
 		"runtime":               "Returns runtime information on the internal state of _murex_",
-		"rx":                    "Regexp pattern matching for file system objects (eg '.*\\.txt')",
+		"rx":                    "Regexp pattern matching for file system objects (eg `.*\\\\.txt`)",
 		"set":                   "Define a local variable and set it's value",
 		"source":                "Import _murex_ code from another file of code block",
 		"struct-keys":           "Outputs all the keys in a structure as a file path",
