@@ -1,10 +1,14 @@
 package events
 
 import (
+	"fmt"
+	"os"
+	"time"
+
 	"github.com/lmorg/murex/debug"
 	"github.com/lmorg/murex/lang"
-	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/ref"
+	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils/json"
 )
@@ -18,8 +22,14 @@ type eventType interface {
 var events = make(map[string]eventType)
 
 // AddEventType registers your event type handlers
-func AddEventType(eventTypeName string, handlerInterface eventType) {
+func AddEventType(eventTypeName string, handlerInterface eventType, err error) error {
+	if err != nil {
+		os.Stderr.WriteString(
+			fmt.Sprintf("cannot add event module %s: %s", eventTypeName, err),
+		)
+	}
 	events[eventTypeName] = handlerInterface
+	return nil
 }
 
 type j struct {
@@ -29,9 +39,19 @@ type j struct {
 
 // Callback is a generic function your event handlers types should hook into so
 // murex functions can remain consistent.
-func Callback(name string, interrupt interface{}, block []rune, fileRef *ref.File, stdout stdio.Io) {
+func Callback(name string, interrupt interface{}, block []rune, fileRef *ref.File, stdout stdio.Io, background bool) {
 	if fileRef == nil {
-		panic("fileRef should not be nil value")
+		if debug.Enabled {
+			panic("fileRef should not be nil value")
+		}
+		os.Stderr.WriteString("Murex error with `event`: '" + name + "'. fileRef should not be nil value. Creating empty object to continue. Please report this https://github.com/lmorg/murex/issues\n")
+		fileRef = &ref.File{
+			Source: &ref.Source{
+				Filename: "UNKNOWN: forked from `event` " + name,
+				Module:   "UNKNOWN: forked from `event` " + name,
+				DateTime: time.Now(),
+			},
+		}
 	}
 
 	json, err := json.Marshal(&j{
@@ -43,10 +63,17 @@ func Callback(name string, interrupt interface{}, block []rune, fileRef *ref.Fil
 		return
 	}
 
-	fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_NEW_MODULE | lang.F_BACKGROUND | lang.F_CREATE_STDIN)
+	var bgProc int
+	if background {
+		bgProc = lang.F_BACKGROUND
+	}
+
+	fork := lang.ShellProcess.Fork(lang.F_FUNCTION | bgProc | lang.F_CREATE_STDIN)
 	fork.Stdin.SetDataType(types.Json)
 	fork.Name.Set("(event)")
 	fork.FileRef = fileRef
+	fork.CCEvent = nil
+	fork.CCExists = nil
 	_, err = fork.Stdin.Write(json)
 	if err != nil {
 		lang.ShellProcess.Stderr.Writeln([]byte("error writing event input: " + err.Error()))
