@@ -80,8 +80,8 @@ func (rl *Instance) resetHintText() {
 	rl.hintText = []rune{}
 }
 
-// SetHintText is a nasty function for force writing a new hint text. Use sparingly!
-func (rl *Instance) SetHintText(s string) {
+// ForceHintTextUpdate is a nasty function for force writing a new hint text. Use sparingly!
+func (rl *Instance) ForceHintTextUpdate(s string) {
 	rl.hintText = []rune(s)
 	rl.writeHintText(true)
 }
